Asphalt-py4j documentation
==========================

Asphalt-py4j provides a means for Asphalt applications to interface with Java libraries or even
Java containers running in other processes, provided they have Py4J gateways running on.

This documentation was not meant as a tutorial for Py4J itself. For that you should consult the
:ref:`Py4J documentation <py4j>`_.

.. _py4j: https://www.py4j.org/contents.html

.. toctree::
   :maxdepth: 1

   configuration
   usage
   versionhistory


Indices and tables
==================

* :ref:`API reference <modindex>`
